<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Provide card markup
 *
 * This file is used to produce HTML for the card detail popup.
 *
 * @link       https://plugins.internetmanagers.nl
 * @since      1.0.0
 *
 * @package    Inbound_Organizer
 * @subpackage Inbound_Organizer/admin/partials
 */
?>

<?php // The close button ?>
<div id="inbound-organizer-card-detail-close">
</div>

<?php // Date and time ?>
<span class="inbound-organizer-card-datetime"><?php echo esc_html( $card['date'] ).' '.esc_html( $card['time'] ); ?></span>
<?php // The column name. The post meta tracking status is returned as array from which the first element is used. ?>
<span><?php echo esc_html( $this->tracking_statuses[ get_post_meta( $post->ID, 'tracking_status' )[0] ] )?></span>
<?php
    // If name, email and/or subject are false, display configuration form to set these fields.
    // Also show the display configuration form if a layout change has been requested.
    if ( !( $card['name'] && $card['email'] && $card['subject'] ) || 
          ( $display_config_form == 1 ) ) {
        echo '<form id="inbound-organizer-card-layout-save">';
        echo '<p><select name="name">';
        echo '<option value="">'.esc_html( __('Select a field to display as NAME', 'inbound-organizer') ).'</option>';
        foreach ( $field_data['fields'] as $field_key => $field_name ) {
            echo '<option '.selected( $field_key, $field_data['mapping']['name'], false ).' value="'.esc_attr( $field_key ).'">'.esc_html( $field_name ).'</option>';
        }
        echo '</select></p>';
        echo '<p><select name="email">';
        echo '<option value="">'.esc_html( __('Select a field to display as EMAIL', 'inbound-organizer') ).'</option>';
        foreach ( $field_data['fields'] as $field_key => $field_name ) {
            echo '<option '.selected( $field_key, $field_data['mapping']['email'], false ).' value="'.esc_attr( $field_key ).'">'.esc_html( $field_name ).'</option>';
        }
        echo '</select></p>';
        echo '<p><select name="subject">';
        echo '<option value="">'.esc_html( __('Select a field to display as SUBJECT', 'inbound-organizer') ).'</option>';
        foreach ( $field_data['fields'] as $field_key => $field_name ) {
            echo '<option '.selected( $field_key, $field_data['mapping']['subject'], false ).' value="'.esc_attr( $field_key ).'">'.esc_html( $field_name ).'</option>';
        }
        echo '</select></p>';
        echo '<button id="inbound-organizer-card-layout-save-button" class="button-primary">'.esc_html( __( 'Save', 'inbound-organizer' ) ).'</button>';
        echo '</form>';
    } else {
?>
<h3><?php 
      // Display name, email and subject fields.
      echo esc_html( $card['name'] ); ?></h3>
<p>
<?php echo esc_html( $card['email'] ); ?><br/>
<?php echo esc_html( $card['subject'] ); ?><br/>
</p>
<?php
    }
?>
<table class="widefat message-fields striped">
<?php 
//Display all data fields of the form submission.
foreach ( $card['fields'] as $fieldname => $fieldvalue) {
    echo '<tr><td class="field-title">'.esc_html( $fieldname ).'</td><td class="field-value">'.
    esc_html( $fieldvalue ).'</td></tr>';
};
?>
</table>
<?php // Display notes field and associated button to save notes. ?>
<form id="inbound-organizer-card-detail-save">
    <textarea name='notes' placeholder="Notes" rows="5"><?php 
        if ( metadata_exists( 'post', $post->ID, 'notes' ) ) {
            echo esc_html( get_post_meta( $post->ID, 'notes' )[0] );
        } ?></textarea>
    <button id="inbound-organizer-card-detail-save-button" class="button-primary"><?php echo esc_html( __( 'Save', 'inbound-organizer' ) ); ?></button>
</form>
<?php
    // Retrieve card color from post meta.
    $color = get_post_meta( $post->ID, 'color', true);
    if ( empty ( $color ) ) {
        $color = 5;
    }
?>
<?php //Display color picker. ?>
<div id="inbound-organizer-card-detail-color-palette"  data-selected="<?php echo esc_attr( $this->color_classes[$color] ); ?>">
    <table class="color-palette">
        <tbody>
            <tr>
                <td class="inborg-gray" data-index="1">&nbsp;</td>
                <td class="inborg-red" data-index="2">&nbsp;</td>
                <td class="inborg-green" data-index="3">&nbsp;</td>
                <td class="inborg-blue" data-index="4">&nbsp;</td>
                <td class="inborg-white" data-index="5" >&nbsp;</td>
                <td class="inborg-brown" data-index="6" >&nbsp;</td>
            </tr>
        </tbody>
    </table>
</div>
<?php //Display icon to configure field assignment to name, email and subject. ?>
<div id="inbound-organizer-card-detail-config"></div>
<?php //Display icon to delete the card from the board. ?>
<div id="inbound-organizer-card-detail-trash"></div>
		
